import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

enum SeniorActionButtonType {
  small,
  medium,
  press,
}

abstract class SeniorActionButtonTheme {
  static Color getButtonColor({
    required Brightness theme,
    required SeniorActionButtonType type
  }) {
    switch (type) {
      case SeniorActionButtonType.press:
        return SeniorColors.primaryColor;
      case SeniorActionButtonType.small:
      case SeniorActionButtonType.medium:
      default:
        return Colors.transparent;
    }
  }

  static double getButtonSize({required SeniorActionButtonType type}) {
    switch (type) {
      case SeniorActionButtonType.press:
        return 60.0;
      case SeniorActionButtonType.small:
        return 32.0;
      case SeniorActionButtonType.medium:
      default:
        return 40.0;
    }
  }

  static Color getButtonIconColor({
    required Brightness theme,
    required SeniorActionButtonType type
  }) {
    switch (type) {
      case SeniorActionButtonType.press:
        return SeniorColors.pureWhite;
      case SeniorActionButtonType.small:
      case SeniorActionButtonType.medium:
      default:
        return SeniorColors.secondaryColor900;
    }
  }

  static double getButtonIconSize({ required SeniorActionButtonType type }) {
    switch (type) {
      case SeniorActionButtonType.small:
        return SeniorTypographyIconSize.text;
      case SeniorActionButtonType.press:
      case SeniorActionButtonType.medium:
      default:
        return SeniorTypographyIconSize.h3;
    }
  }
}  

class SeniorActionButton extends StatelessWidget {
  final IconData icon;
  final VoidCallback onPressed;
  final SeniorActionButtonType type;

  SeniorActionButton({
    required Key key,
    required this.icon,
    required this.onPressed,
    required this.type,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {  
    Brightness theme = MediaQuery.of(context).platformBrightness;
      
    return SizedBox(
      child: TextButton(
        child: FaIcon(
          this.icon,
          size: SeniorActionButtonTheme.getButtonIconSize(type: this.type),
        ),
        onPressed: this.onPressed,
        style: TextButton.styleFrom(
          primary: SeniorActionButtonTheme.getButtonIconColor(theme: theme, type: this.type),
          backgroundColor: SeniorActionButtonTheme.getButtonColor(theme: theme, type: this.type),
          shape: CircleBorder(),
        ),
      ),
      height: SeniorActionButtonTheme.getButtonSize(type: this.type),
      width: SeniorActionButtonTheme.getButtonSize(type: this.type),
    );
  }
}
